.. _sshconfig:

SSHConfig
=========

The :class:`scherbelberg.SSHConfig` class is a very simple, immutable class for describing ``ssh`` connection settings.

The ``SSHConfig`` Class
-----------------------

.. autoclass:: scherbelberg.SSHConfig
    :members:
